@@ -16,6 +16,12 @@ pub mod data;
 pub mod event;
 pub mod texture;
 
+pub use canvas::Canvas;
+pub use canvas::DrawDestination;
+pub use canvas::Screen;
+pub use event::Event;
+pub use texture::Texture;
+
 #[cfg(feature = "f32-canvas")]
 pub type GridUnit = f32;
 
