@@ -1,4 +1,4 @@
-use crate::canvas::Canvas;
+use crate::canvas::{Canvas, DrawDestination};
 use crate::ffi;
 use crate::Color;
 use crate::GridUnit;
